/*
 * Copyright (c) 2007-2010, University of Maryland
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list of conditions
 * and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 * and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of the University of Maryland nor the names of its contributors may be used to
 * endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * ACE Components were written in the ADAPT Project at the University of
 * Maryland Institute for Advanced Computer Study.
 */
// $Id: UserSessionTracker.java 9 2010-06-22 18:00:44Z toaster $

package edu.umiacs.ace.monitor.users;

import java.util.HashSet;
import java.util.Set;
import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpSessionEvent;
import javax.servlet.http.HttpSessionListener;
import org.apache.log4j.Logger;

/**
 * Web application lifecycle listener.
 * @author toaster
 */
public class UserSessionTracker implements HttpSessionListener {

    private static final Logger LOG = Logger.getLogger(UserSessionTracker.class);
    private static final Set<HttpSession> sessionMap = new HashSet<HttpSession>();

    @Override
    public synchronized void sessionCreated( HttpSessionEvent arg0 ) {
        HttpSession session = arg0.getSession();
        LOG.trace("Adding session " + session.getCreationTime());

        sessionMap.add(session);
    }

    @Override
    public synchronized void sessionDestroyed( HttpSessionEvent arg0 ) {
        sessionMap.remove(arg0.getSession());
    }

    public static synchronized void refreshAll() {

        LOG.trace("refreshAll called, removing all registered sessions");
        for ( HttpSession session : new HashSet<HttpSession>(sessionMap) ) {
            LOG.trace("Removing session: " + session.getCreationTime());
            session.invalidate();
        }
    }
}
